Crochet! Magazine - Defining Crochet
Description: Crochet! Magazine is the official magazine of the Crochet Guild of America. In its pages, you'll find fabulous crochet patterns and helpful articles that support its tagline -- Defining Crochet.
Keywords: crochet, crochet magazine, crochet patterns

Already a print or digital subscriber?

Not a subscriber?
Click here to find out more!

- FEATURED IN OUR SPRING ISSUE
  At Home -- Argemone Motif Blanket
  Design by Robyn Chachula
  Inspired by the argemone flower, textures and colors combine for unforgettable results in ...
- FEATURED IN OUR SPRING ISSUE
  Beginner's Corner -- Merida Cuff
  Design by Beth Hulevitch
  Make this sweet, elegant cuff in minutes.
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Lisbon Shawl
  Design by Elisabeth Davis de Herraiz
  This shawl has an exquisitely simple increasing central point to make a classic triangle ...
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Penelope Pineapple Scarf
  Design by Darla Fanton
  Practice your pineapple skills with a series of intricate but rhythmic ...
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Refractions Tunisian Wrap
  Design by Linda Dean
  Fascinating triangle short rows are repeated to create this ...
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Spree Circle & Square Shawl
  Design by Diane K. Moyer
  One easy motif in a standout yarn is the beautiful foundation of this ...
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Strata Market Tote
  Design by NTmaglia
  Even the most basic of outfits will become a showstopping ensemble when this tote is added ...
- FEATURED IN OUR SPRING ISSUE
  Dress It Up -- Trip Trap Wrap
  Design by April Garwood
  A departure from the ordinary, this shawl is composed of six trapezoid shapes, and it ...
- FEATURED IN OUR SPRING ISSUE
  Easy As 1-2-3 -- Butterfly Nest Scarf
  Design by Tanis Galik
  Repetition of simple stitches interspersed with spectacular Solomon's ...
- FEATURED IN OUR SPRING ISSUE
  Fiber Focus -- Linen
  By Jackie Daugherty
  Linen is a fiber with a long history.
- FEATURED IN OUR SPRING ISSUE
  Great Yarns, Great Styles -- Adana Tote
  Design by Mona Modica for Creative Yarn Source
  Make a bold and graphic statement with this fantastically shaped bag.
- FEATURED IN OUR SPRING ISSUE
  Great Yarns, Great Styles -- Eva Folk Jumper
  Design by Jennifer E. Ryan
  Make this one-of-a-kind dress for a little girl who wants to shine.
- FEATURED IN OUR SPRING ISSUE
  Great Yarns, Great Styles -- Milan Shoulder Bag
  Design by Debra Arch
  Add some drama to your wardrobe with this eye-catching tote.
- FEATURED IN OUR SPRING ISSUE
  In Stitches -- Shells & V-Stitches and Clusters & ...
  Designs by Annie's
  Learn two new clever stitches for your crochet repertoire!
- FEATURED IN OUR SPRING ISSUE
  Learn It! Do It! -- Learn to Crochet With Beads
  By Brenda Bourg
  Learn how to work beads into your crochet projects for added interest!
- FEATURED IN OUR SPRING ISSUE
  Learn It! Do It! -- Learn to Felt Crochet
  By Angelia Robinson
  Learn one of the most basic and fun ways to felt crochet.
- FEATURED IN OUR SPRING ISSUE
  Learn It! Do It! -- Masika Beaded Scarf
  By Brenda Bourg
  Show off your new bead crochet skills with this sophisticated and ...
- FEATURED IN OUR SPRING ISSUE
  Learn It! Do It! -- Shimmery Felted Bangles
  By Angelia Robinson
  A little sparkle elevates this beginner bangle into a statement ...
- FEATURED IN OUR SPRING ISSUE
  Motifs in Minutes -- Bruges Blossom Square & Picot ...
  Designs by Ellen Gormley
  Get a taste of Bruges crochet and practice picots in these intriguing ...
- FEATURED IN OUR SPRING ISSUE
  Pay It Forward -- Palatine Scarf
  Design by Bonnie Barker
  This simple scarf and sophisticated design is perfect for a last-minute gift. The scarf ...
- FEATURED IN OUR SPRING ISSUE
  Slip Into Style -- Crimped Lace Anorak
  Design by Jill Hanratty
  Get a figure-flattering fit with this lightweight jacket made with a ...
- FEATURED IN OUR SPRING ISSUE
  Slip Into Style -- Geneva Sleeveless Jacket
  Design by Mary Jane Hall
  Generous in styling, this sleeveless jacket is an easy layering piece ...
- FEATURED IN OUR SPRING ISSUE
  Slip Into Style -- Kista Pullover
  Design by Lena Skvagerson for Annie's Signature Designs
  This lovely cable and row design is made of a season-spanning linen-blend yarn.
- FEATURED IN OUR SPRING ISSUE
  Slip Into Style -- Ravenna Tank
  Design by Laura Gebhardt
  The yarn makes the magic in this memorable and stylish tank.
- FEATURED IN OUR SPRING ISSUE
  Slip Into Style -- Velana Cardigan
  Design by Angelia Robinson
  This cardigan epitomizes modern grace whether it is dressed up or dressed casually.
- FEATURED IN OUR SPRING ISSUE
  Tots 2 Teens -- Brighton Girl Cardigan
  Design by Tammy Hildebrand
  This exciting lace pattern paired with mini motifs makes a gift-worthy ...
- FEATURED IN OUR SPRING ISSUE
  Tots 2 Teens -- Hanover Baby Blanket
  Design by Tanis Galik
  Tunisian crochet in columns turns this unisex baby blanket on its end.

- CURRENT ISSUE
- GREAT PRODUCT FINDS

# Our Spring Issue

#### Cover Story:

Light Layers!
Great Transitional Pieces

#### Also Featured:

4 Splendid Spring Shawls!
Clever Construction, Simple Style
Unique Bracelets!
On-Trend Accessories — Two Different Techniques

# Great Product Finds

Square® Crochet Hooks by Kollage Yarns

Give crocheters a hook and a ball of yarn and they can crochet just about anything! And while the tools are simple, having the right crochet hook helps us do our best work and can save hours of frustration. Kollage Yarns has just come out with a new American-made hook that is not only beautiful to look at, but designed to be ergonomically suited to your hands, decreasing stress and strain. The square wood handles sourced from U.S.-grown maple are warm to the touch and fit comfortably in your hand, making the hooks a good choice for crocheters who have arthritis, carpal tunnel or stiffness in their finger or joints.

The in-line hooks come with either rounded or pointed tips to match personal preference and ease of use for all types of crochet projects. Both styles come in sizes A/0/2mm through L/11/8mm hooks with smaller-size hooks made of stainless steel and larger sizes manufactured from high-grade aluminum.

Spring 2016
Jump into spring with an instant download of 25 innovative and inspiring crochet patterns, including the light and airy Ravenna Tank featured on the cover! Prepare for transitional weather with projects from easy pieces for layering to sleeveless tops. Build your spring wardrobe with both classic and fashion forward crochet garments such as hoodies, cardigans, jackets, tanks and tunics. Scarves, totes and shawls abound in this issue! The spring issue is rounded out with beautiful crochet projects for the home and an adorable dress for little girls! Don't wait -- download (or subscribe) today!

Note From The Editor | Learn It, Do It!
We have many new features in this exciting spring issue! In addition to a collection of very pretty, fun, innovative and satisfying projects, I hope that you find Crochet! to be entertaining and educational. For that reason, we are adding the Yarn Shop Profile, the Fiber Focus series and the Blogger Spotlight. Read more | Learn to Felt Crochet By Angelia Robinson Learn one of the most basic and fun ways to felt crochet.

Great Product Finds
Square® Crochet Hooks by Kollage Yarns

Give crocheters a hook and a ball of yarn and they can crochet just about anything! And while the tools are simple, having the right crochet hook helps us do our best work and can save hours of frustration. Kollage Yarns has just come out with a new American-made hook that is not only beautiful to look at, but designed to be ergonomically suited to your hands, decreasing stress and strain. The square wood handles sourced from U.S.-grown maple are warm to the touch and fit comfortably in your hand, making the hooks a good choice for crocheters who have arthritis, carpal tunnel or stiffness in their finger or joints.

The in-line hooks come with either rounded or pointed tips to match personal preference and ease of use for all types of crochet projects. Both styles come in sizes A/0/2mm through L/11/8mm hooks with smaller-size hooks made of stainless steel and larger sizes manufactured from high-grade aluminum.

Get a FREE issue of Crochet! magazine
just for giving it a try! (A $7.99 value, FREE!)

Express your creativity plus save time and money! You'll be thrilled and inspired with exciting NEW crochet patterns, complete step-by-step instructions, full-color photos and all the handy, time-saving tips and techniques in every issue of Crochet! See for yourself, order today! |
| YES! Please send me my FREE ISSUE of Crochet! magazine and start my subscription. If I like my free issue, I'll simply pay the attached invoice and get one full year (4 more issues) for only $21.97 plus $2.98 delivery. That's one issue FREE and four more as part of my subscription! I'll also get a digital edition of each issue at no extra cost, including the free issue, plus two years of digital back issues with my paid subscription! In the unlikely event that I'm not pleased with my free issue, I'll return the invoice marked "cancel" and keep that issue as your gift to me -- and owe absolutely nothing.
First Name: | Last Name: |
Address: | Address 2: |
City: | State: | ZIP Code:
Email: |
| Don't miss out! Get email alerts about your new magazine subscription, special offers and savings from Crochet! and Annie's. Questions? Read our online privacy pledge.
Offer valid in U.S. only! Canadian Orders | Give a Gift Subscription!

[X] Close